Checkbox

Struct Checkbox 

pub struct Checkbox { /* private fields */ }
Available on crate feature checkbox only.
A Checkbox struct that encapsulates a listbox for item selection and a set of picked (selected) indices. It allows for multiple selections, toggling the selection state of items, and navigating through the items.

Implementations

Source

impl Checkbox

pub fn from_displayable<E: Display, I: IntoIterator<Item = E>>(items: I) -> Self

Creates a new Checkbox from a vector of fmt::Display.

pub fn from_styled_graphemes(items: Vec<StyledGraphemes>) -> Self

Creates a new Checkbox from a vector of StyledGraphemes.

pub fn new_with_checked<T: Display, I: IntoIterator<Item = (T, bool)>>( iter: I, ) -> Self

Creates a Checkbox from an iterator of tuples where the first element implements the Display trait and the second element is a bool indicating if the item is picked (selected). Each item is added to the listbox, and the set of picked indices is initialized based on the bool values.

pub fn items(&self) -> &Vec<StyledGraphemes>

Returns a reference to the vector of items in the listbox.

pub fn position(&self) -> usize

Returns the current position of the cursor within the listbox.

pub fn picked_indexes(&self) -> &HashSet<usize>

Returns a reference to the set of picked (selected) indices.

pub fn get(&self) -> Vec<StyledGraphemes>

Retrieves the items at the picked (selected) indices as a vector of strings.

pub fn toggle(&mut self)

Toggles the selection state of the item at the current cursor position within the listbox.

pub fn backward(&mut self) -> bool

Moves the cursor backward in the listbox, if possible. Returns true if the cursor was successfully moved backward, false otherwise.

pub fn forward(&mut self) -> bool

Moves the cursor forward in the listbox, if possible. Returns true if the cursor was successfully moved forward, false otherwise.

pub fn move_to_head(&mut self)

Moves the cursor to the head (beginning) of the listbox.

pub fn move_to_tail(&mut self)

Moves the cursor to the tail of the listbox.