pub struct State {
pub checkbox: Checkbox,
pub config: Config,
}Available on crate feature
checkbox only.Expand description
Represents the state of a Checkbox component.
This state includes not only the checkbox itself but also various attributes that determine how the checkbox and its items are displayed. These attributes include symbols for indicating active and inactive items, styles for selected and unselected lines, and the number of lines available for rendering.
Fields
checkbox: CheckboxThe Checkbox component to be rendered.
config: ConfigConfiguration for rendering and behavior.