Module cursor

Module cursor 

Modules

len

Structs

Cursor
A generic cursor structure for navigating and manipulating collections. It maintains a position within the collection and provides methods to move forward, backward, to the head, and to the tail of the collection. It requires the collection to implement the Len trait. The cyclic parameter allows the cursor to cycle through the collection.