JsonStream

Struct JsonStream 

pub struct JsonStream { /* private fields */ }
Available on crate feature jsonstream only.
Represents a stream of JSON data, allowing for efficient navigation and manipulation.

Implementations

Source

impl JsonStream

pub fn new<'a, I: IntoIterator<Item = &'a Value>>(iter: I) -> Self

Source

impl JsonStream

pub fn rows(&self) -> &[Row]

Returns a reference to the underlying vector of rows.

pub fn extract_rows_from_current(&self, n: usize) -> Vec<Row>

Extracts a specified number of rows from the current position in JSON stream.

pub fn toggle(&mut self)

Toggles the visibility of a node at the cursor’s current position.

pub fn set_nodes_visibility(&mut self, collapsed: bool)

Sets the visibility of all rows in JSON stream.

pub fn up(&mut self) -> bool

Moves the cursor backward through JSON stream.

pub fn head(&mut self) -> bool

Moves the cursor to the head position in JSON stream.

pub fn down(&mut self) -> bool

Moves the cursor forward through JSON stream.

pub fn tail(&mut self) -> bool

Moves the cursor to the last position in JSON stream.