State

Struct State 

pub struct State {
    pub listbox: Listbox,
    pub config: Config,
}
Available on crate feature listbox only.
Represents the state of a Listbox component, including its appearance and behavior. This state includes the currently selected item, styles for active and inactive items, and the number of lines available for rendering the listbox.

Fields

listbox: Listbox

The Listbox component to be rendered.

config: Config

Configuration for rendering and behavior.