pub struct Spinner {
pub frames: Frame,
pub suffix: String,
pub duration: Duration,
}Available on crate feature
spinner only.Expand description
A spinner that can be used to indicate loading or processing states.
Fields
frames: FrameThe frames of the spinner, which are the characters that will be displayed in a rotating manner.
suffix: StringA suffix that will be displayed alongside the spinner.
duration: DurationThe duration between frame updates.
Implementations