TextEditor

Struct TextEditor 

pub struct TextEditor(/* private fields */);
Available on crate feature texteditor only.
A text editor that supports basic editing operations such as insert, delete, and overwrite. It utilizes a cursor to navigate and manipulate the text.

Implementations

Source

impl TextEditor

pub fn new<S: AsRef<str>>(s: S) -> Self

pub fn text(&self) -> StyledGraphemes

Returns the current text including the cursor.

pub fn text_without_cursor(&self) -> StyledGraphemes

Returns the text without the cursor.

pub fn position(&self) -> usize

Returns the current position of the cursor within the text.

pub fn masking(&self, mask: char) -> StyledGraphemes

Masks all characters except the cursor with the specified mask character.

pub fn replace(&mut self, new: &str)

Replaces the current text with new text and positions the cursor at the end.

pub fn insert(&mut self, ch: char)

Inserts a character at the current cursor position.

pub fn insert_chars(&mut self, vch: &Vec<char>)

pub fn overwrite(&mut self, ch: char)

Overwrites the character at the current cursor position with the specified character.

pub fn overwrite_chars(&mut self, vch: &Vec<char>)

pub fn erase(&mut self)

Erases the character before the cursor position.

pub fn erase_all(&mut self)

Clears all text and resets the editor to its default state.

pub fn erase_to_previous_nearest(&mut self, word_break_chars: &HashSet<char>)

Erases the text from the current cursor position to the nearest previous character in word_break_chars.

pub fn move_to_previous_nearest(&mut self, word_break_chars: &HashSet<char>)

Moves the cursor to the nearest previous character in word_break_chars.

pub fn erase_to_next_nearest(&mut self, word_break_chars: &HashSet<char>)

Erases the text from the current cursor position to the nearest next character in word_break_chars.

pub fn move_to_next_nearest(&mut self, word_break_chars: &HashSet<char>)

Moves the cursor to the nearest next character in word_break_chars.

pub fn move_to_head(&mut self)

Moves the cursor to the beginning of the text.

pub fn move_to_tail(&mut self)

Moves the cursor to the end of the text.

pub fn shift(&mut self, backward: usize, forward: usize) -> bool

pub fn backward(&mut self) -> bool

Moves the cursor one position backward, if possible.

pub fn forward(&mut self) -> bool

Moves the cursor one position forward, if possible.