pub struct Text(/* private fields */);Available on crate feature
text only.Implementations
Sourceimpl Text
impl Text
Sourcepub fn from_styled_graphemes(lines: Vec<StyledGraphemes>) -> Self
pub fn from_styled_graphemes(lines: Vec<StyledGraphemes>) -> Self
Creates a new Text from styled graphemes without parsing a string.
Useful when the caller already has styled content prepared.
Sourcepub fn replace_contents(&mut self, text: Vec<StyledGraphemes>)
pub fn replace_contents(&mut self, text: Vec<StyledGraphemes>)
Replaces the contents with new contents and adjusts the position if necessary.
Sourcepub fn items(&self) -> &Vec<StyledGraphemes>
pub fn items(&self) -> &Vec<StyledGraphemes>
Returns a reference to the vector of items in the listbox.