pub struct TextEditor(/* private fields */);texteditor only.Expand description
A text editor that supports basic editing operations such as insert, delete, and overwrite. It utilizes a cursor to navigate and manipulate the text.
Implementations
Sourceimpl TextEditor
impl TextEditor
pub fn new<S: AsRef<str>>(s: S) -> Self
Sourcepub fn text(&self) -> StyledGraphemes
pub fn text(&self) -> StyledGraphemes
Returns the current text including the cursor.
Sourcepub fn text_without_cursor(&self) -> StyledGraphemes
pub fn text_without_cursor(&self) -> StyledGraphemes
Returns the text without the cursor.
Sourcepub fn masking(&self, mask: char) -> StyledGraphemes
pub fn masking(&self, mask: char) -> StyledGraphemes
Masks all characters except the cursor with the specified mask character.
Sourcepub fn replace(&mut self, new: &str)
pub fn replace(&mut self, new: &str)
Replaces the current text with new text and positions the cursor at the end.
pub fn insert_chars(&mut self, vch: &Vec<char>)
Sourcepub fn overwrite(&mut self, ch: char)
pub fn overwrite(&mut self, ch: char)
Overwrites the character at the current cursor position with the specified character.
pub fn overwrite_chars(&mut self, vch: &Vec<char>)
Sourcepub fn erase_to_previous_nearest(&mut self, word_break_chars: &HashSet<char>)
pub fn erase_to_previous_nearest(&mut self, word_break_chars: &HashSet<char>)
Erases the text from the current cursor position to the nearest previous character in word_break_chars.
Sourcepub fn move_to_previous_nearest(&mut self, word_break_chars: &HashSet<char>)
pub fn move_to_previous_nearest(&mut self, word_break_chars: &HashSet<char>)
Moves the cursor to the nearest previous character in word_break_chars.
Sourcepub fn erase_to_next_nearest(&mut self, word_break_chars: &HashSet<char>)
pub fn erase_to_next_nearest(&mut self, word_break_chars: &HashSet<char>)
Erases the text from the current cursor position to the nearest next character in word_break_chars.
Sourcepub fn move_to_next_nearest(&mut self, word_break_chars: &HashSet<char>)
pub fn move_to_next_nearest(&mut self, word_break_chars: &HashSet<char>)
Moves the cursor to the nearest next character in word_break_chars.
Sourcepub fn move_to_head(&mut self)
pub fn move_to_head(&mut self)
Moves the cursor to the beginning of the text.
Sourcepub fn move_to_tail(&mut self)
pub fn move_to_tail(&mut self)
Moves the cursor to the end of the text.
pub fn shift(&mut self, backward: usize, forward: usize) -> bool