Available on crate feature
tree only.Enums
- Kind
- Represents the kind of a node in a tree structure.
- Node
- Represents a node within a tree structure.
Type Aliases
- Path
- A type alias for a path in the tree, represented as a sequence of indices.